@@ -1,5 +1,7 @@
 //! Provides built-in [Subcontext](crate::Subcontext) implementations.
 
+mod event_context;
 mod scheduler_context;
 
+pub use event_context::*;
 pub use scheduler_context::*;
