@@ -1,11 +1,13 @@
 mod context;
 mod core_function;
 mod engine;
+mod plugin;
 mod scheduler;
 mod state;
 
 pub use context::*;
 pub use core_function::*;
 pub use engine::*;
+pub use plugin::*;
 pub use scheduler::*;
 pub use state::*;
