@@ -6,9 +6,9 @@ use crate::*;
 pub(crate) struct CorePlugin;
 
 impl Plugin for CorePlugin {
-    fn setup(&mut self, engine_builder: EngineBuilder) -> EngineBuilder {
-        engine_builder
+    fn setup(&mut self, engine_builder: EngineBuilder) -> PluginResult {
+        Ok(engine_builder
             .with_subcontext(SchedulerContext::new())
-            .with_subcontext(EventContext::<Event>::default())
+            .with_subcontext(EventContext::<Event>::default()))
     }
 }
